@@ -346,7 +346,7 @@ class bigjob_agent:
                     else:
                         arguments_list = eval(job_dict["Arguments"])                    
                     for i in arguments_list:
-                        arguments = arguments + " " + i
+                        arguments = arguments + " " + str(i)
                         
                 environment = os.environ
                 envi = ""
@@ -473,7 +473,7 @@ class bigjob_agent:
                     #        command = command + " : "
                 elif self.LAUNCH_METHOD=="ibrun" and spmdvariation.lower()=="mpi": 
                     # Non MPI launch is handled via standard SSH
-                    command = envi + "mpirun_rsh   -np " + str(numberofprocesses) + " -hostfile " + machinefile + " " + executable + " " + arguments                   
+                    command = envi + "mpirun_rsh   -np " +str(numberofprocesses) + " -hostfile " + machinefile + "  `build_env.pl` " + executable + " " + arguments
                 elif (spmdvariation.lower()!="mpi"):
                     command =  envi + executable + " " + arguments
                     # In particular for Condor - if executable is staged x flag is not set
@@ -489,7 +489,7 @@ class bigjob_agent:
                     command ="cd " + workingdirectory + "; " + command
                 else: # ssh launch is default
                     if (spmdvariation.lower( )=="mpi"):
-                        command = "cd " + workingdirectory + "; " + envi +  self.MPIRUN + " -np " + numberofprocesses + " -machinefile " + machinefile + " " + command
+                        command = "cd " + workingdirectory + "; " + envi +  self.MPIRUN + " -np " + numberofprocesses + " -machinefile " + machinefile + " " + executable + " " + arguments
                     elif host == "localhost":
                         command ="cd " + workingdirectory + "; " + command
                     else:    
